@@ -7,9 +7,9 @@ import time
 
 
 
-def launch_ssh(password, token):
+def launch_ssh(token, password=""):
 
-  run_command("kill $(ps aux | grep 'ngrok' | awk '{print $2}')")
+  os.system("kill $(ps aux | grep 'ngrok' | awk '{print $2}')")
   #Download ngrok
   run_command("wget -q -nc https://bin.equinox.io/c/4VmDzA7iaHb/ngrok-stable-linux-amd64.zip")
   run_command("unzip -qq -n ngrok-stable-linux-amd64.zip")
@@ -17,12 +17,12 @@ def launch_ssh(password, token):
   run_with_pipe("echo root:{} | sudo chpasswd".format(password))
   run_command("mkdir -p /var/run/sshd")
   os.system("echo 'PermitRootLogin yes' >> /etc/ssh/sshd_config")
-  os.system('echo "PasswordAuthentication yes" >> /etc/ssh/sshd_config')
+  if password:
+    os.system('echo "PasswordAuthentication yes" >> /etc/ssh/sshd_config')
   os.system('echo "LD_LIBRARY_PATH=/usr/lib64-nvidia" >> /root/.bashrc')
   os.system('echo "export LD_LIBRARY_PATH" >> /root/.bashrc')
-  run_command('/usr/sbin/sshd -D')
+  os.system('/usr/sbin/sshd -D &')
   print("Copy authtoken from https://dashboard.ngrok.com/auth")
-  import getpass
 
   #Create tunnel
   #get_ipython().system_raw('./ngrok authtoken $authtoken && ./ngrok tcp 22 &')
